==> EspoCRM-8.0.5.zip: EspoCRM-8.0.5/application/Espo/Tools/Kanban/Api/PutOrder.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2023 Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko
 * Website: https://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Tools\Kanban\Api;

use Espo\Core\Api\Action;
use Espo\Core\Api\Request;
use Espo\Core\Api\Response;
use Espo\Core\Api\ResponseComposer;
use Espo\Core\Exceptions\BadRequest;
use Espo\Tools\Kanban\KanbanService;

class PutOrder implements Action
{
    public function __construct(private KanbanService $service)
    {}

    public function process(Request $request): Response
    {
        $data = $request->getParsedBody();

        $entityType = $data->entityType ?? null;
        $group = $data->group ?? null;
        $ids = $data->ids ?? null;

        if (empty($entityType) || !is_string($entityType)) {
            throw new BadRequest();
        }

        if (empty($group) || !is_string($group)) {
            throw new BadRequest();
        }

        if (!is_array($ids)) {
            throw new BadRequest();
        }

        $this->service->order($entityType, $group, $ids);

        return ResponseComposer::json(true);
    }
}

==> EspoCRM-8.4.2.zip: EspoCRM-8.4.2/application/Espo/Tools/Kanban/Api/PutOrder.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM – Open Source CRM application.
 * Copyright (C) 2014-2024 Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko
 * Website: https://www.espocrm.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Tools\Kanban\Api;

use Espo\Core\Api\Action;
use Espo\Core\Api\Request;
use Espo\Core\Api\Response;
use Espo\Core\Api\ResponseComposer;
use Espo\Core\Exceptions\BadRequest;
use Espo\Tools\Kanban\KanbanService;

class PutOrder implements Action
{
    public function __construct(private KanbanService $service)
    {}

    public function process(Request $request): Response
    {
        $data = $request->getParsedBody();

        $entityType = $data->entityType ?? null;
        $group = $data->group ?? null;
        $ids = $data->ids ?? null;

        if (empty($entityType) || !is_string($entityType)) {
            throw new BadRequest();
        }

        if (empty($group) || !is_string($group)) {
            throw new BadRequest();
        }

        if (!is_array($ids)) {
            throw new BadRequest();
        }

        $this->service->order($entityType, $group, $ids);

        return ResponseComposer::json(true);
    }
}
